Error

Enum Error 

pub enum Error {
    InvalidTokenizer(String),
    Io(Error),
    InvalidChatTemplate(String),
    AmbiguousChatTemplate {
        available: Vec<String>,
    },
    RenderTemplate(Error),
    FinalMsgNotInChat,
    Encode(Error),
    Serialize(Error),
}
Errors produced while constructing tokenizers or rendering chat templates.

Variants



InvalidTokenizer(String)

Tokenizer metadata is malformed or inconsistent.



Io(Error)

Reading tokenizer or template data failed.



InvalidChatTemplate(String)

Chat-template metadata is malformed.



AmbiguousChatTemplate

A named template collection has no selectable default.

Fields

available: Vec<String>

Names of the templates present in the collection.



RenderTemplate(Error)

MiniJinja could not compile or render the template.



FinalMsgNotInChat

continue_final_message is set but the final message does not appear in the chat after
applying the chat template! This can happen if the chat template deletes portions of the final message. Please verify the chat template and final message in your chat to ensure they are compatible.



Encode(Error)

The Hugging Face tokenizer could not encode input or be constructed.



Serialize(Error)

JSON serialization of template inputs failed.