pub struct ApplyChatTemplateArgs<'a, I, R = Role, T = String>{
pub conversations: I,
pub tools: Option<&'a [Value]>,
pub documents: Option<&'a [Document]>,
pub model_id: &'a str,
pub chat_template_id: Option<&'a str>,
pub add_generation_prompt: Option<bool>,
pub continue_final_message: Option<bool>,
pub template_kwargs: Option<&'a Map<String, Value>>,
}Expand description
Inputs for rendering one or more conversations with a chat template.
Fields
conversations: IConversations to render.
tools: Option<&'a [Value]>Tool definitions exposed to the template.
documents: Option<&'a [Document]>Documents exposed to the template.
model_id: &'a strStable model identifier used to cache the compiled template.
chat_template_id: Option<&'a str>Identifier of a template already registered in the environment.
add_generation_prompt: Option<bool>Whether to ask the template to append its generation prompt.
continue_final_message: Option<bool>Whether to trim the rendering after the final input message.
template_kwargs: Option<&'a Map<String, Value>>Additional variables exposed to the template.